summaryrefslogtreecommitdiff
path: root/modules/libsrtp
diff options
context:
space:
mode:
authorAlfred E. Heggestad <aeh@db.org>2014-06-21 01:38:15 +0200
committerAlfred E. Heggestad <aeh@db.org>2014-06-21 01:38:15 +0200
commitbdafb601b0bfe3096e49df3df5feef8d68c5cfde (patch)
tree78c10f59fa85f0d3b0e1dc6f885b457bfadd9f0f /modules/libsrtp
parent30214ad24af47d020871f8d4d5d62f113865645e (diff)
updated some module documentation
Diffstat (limited to 'modules/libsrtp')
-rw-r--r--modules/libsrtp/sdes.c9
-rw-r--r--modules/libsrtp/sdes.h10
-rw-r--r--modules/libsrtp/srtp.c4
3 files changed, 12 insertions, 11 deletions
diff --git a/modules/libsrtp/srtp.c b/modules/libsrtp/srtp.c
index 244d7cc..7cb2592 100644
--- a/modules/libsrtp/srtp.c
+++ b/modules/libsrtp/srtp.c
@@ -272,7 +272,7 @@ static int sdp_enc(struct menc_st *st, struct sdp_media *m,
if (err)
return err;
- return sdes_encode_crypto(m, tag, suite, key, olen);
+ return libsrtp_sdes_encode_crypto(m, tag, suite, key, olen);
}
@@ -309,7 +309,7 @@ static bool sdp_attr_handler(const char *name, const char *value, void *arg)
struct crypto c;
(void)name;
- if (sdes_decode_crypto(&c, value))
+ if (libsrtp_sdes_decode_crypto(&c, value))
return false;
if (0 != pl_strcmp(&c.key_method, "inline"))
diff --git a/modules/libsrtp/sdes.c b/modules/libsrtp/sdes.c
index a750432..1a90f3f 100644
--- a/modules/libsrtp/sdes.c
+++ b/modules/libsrtp/sdes.c
@@ -1,5 +1,5 @@
/**
* @file sdes.c SDP Security Descriptions for Media Streams (RFC 4568)
*
* Copyright (C) 2010 Creytiv.com
*/
@@ -8,10 +8,11 @@
#include "sdes.h"
-const char sdp_attr_crypto[] = "crypto";
+static const char sdp_attr_crypto[] = "crypto";
-int sdes_encode_crypto(struct sdp_media *m, uint32_t tag, const char *suite,
+int libsrtp_sdes_encode_crypto(struct sdp_media *m, uint32_t tag,
+ const char *suite,
const char *key, size_t key_len)
{
return sdp_media_set_lattr(m, true, sdp_attr_crypto, "%u %s inline:%b",
@@ -22,7 +23,7 @@ int sdes_encode_crypto(struct sdp_media *m, uint32_t tag, const char *suite,
/* http://tools.ietf.org/html/rfc4568
* a=crypto:<tag> <crypto-suite> <key-params> [<session-params>]
*/
-int sdes_decode_crypto(struct crypto *c, const char *val)
+int libsrtp_sdes_decode_crypto(struct crypto *c, const char *val)
{
struct pl tag, key_prms;
int err;
@@ -1,5 +1,5 @@
/**
- * @file sdes.c SDP Security Descriptions for Media Streams (RFC 4568)
+ * @file libsrtp/sdes.c SDP Security Descriptions (RFC 4568)
*
* Copyright (C) 2010 Creytiv.com
diff --git a/modules/libsrtp/sdes.h b/modules/libsrtp/sdes.h
index 66cc2f1..8c2c1f9 100644
--- a/modules/libsrtp/sdes.h
+++ b/modules/libsrtp/sdes.h
@@ -1,5 +1,5 @@
/**
* @file sdes.h SDP Security Descriptions for Media Streams (RFC 4568) API
*
* Copyright (C) 2010 Creytiv.com
*/
@@ -15,8 +15,8 @@ struct crypto {
struct pl sess_prms; /* optional */
};
-extern const char sdp_attr_crypto[];
-int sdes_encode_crypto(struct sdp_media *m, uint32_t tag, const char *suite,
- const char *key, size_t key_len);
-int sdes_decode_crypto(struct crypto *c, const char *val);
+int libsrtp_sdes_encode_crypto(struct sdp_media *m, uint32_t tag,
+ const char *suite,
+ const char *key, size_t key_len);
+int libsrtp_sdes_decode_crypto(struct crypto *c, const char *val);
@@ -1,5 +1,5 @@
/**
- * @file sdes.h SDP Security Descriptions for Media Streams (RFC 4568) API
+ * @file libsrtp/sdes.h SDP Security Descriptions (RFC 4568) API
*
* Copyright (C) 2010 Creytiv.com